﻿using EVCB_OCPP.TaskScheduler.Models;
using EVCB_OCPP.TaskScheduler.Services;
using Microsoft.Extensions.Logging;
using Quartz;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace EVCB_OCPP.TaskScheduler.Jobs
{
    [DisallowConcurrentExecution]
    internal class ConnectionStatisticsJob : IJob
    {
        public ConnectionStatisticsJob(DatabaseService databaseService, ILogger<ConnectionStatisticsJob> logger)
        {
            this.database = databaseService;
            this.logger = logger;
        }
        private readonly DatabaseService database;
        private readonly ILogger<ConnectionStatisticsJob> logger;

        public async Task Execute(IJobExecutionContext context)
        {
            logger.LogTrace(this.ToString() + " :Starting........");

            List<ConnectionStatistics> connectionStatistics = new List<ConnectionStatistics>();
            var customers = await database.GetCustomerInfos();
            var storagedChargers = await database.GetChargerAmount(connected: false);
            var connectedChargers = await database.GetChargerAmount(connected: true);
            var connectedConnectors = await database.GetConnectorAmount();
            foreach (var customer in customers)
            {
                if (customer.Name == "PHT") continue;
                connectionStatistics.Add(new ConnectionStatistics()
                {
                    CustomerName = customer.Name,
                    StationName = customer.Name,
                    StoragedChargerAmount = storagedChargers.Where(x => x.CustomerName == customer.Name).Select(x => x.Charger_Count).FirstOrDefault(),
                    UsedChargerAmount = connectedChargers.Where(x => x.CustomerName == customer.Name).Select(x => x.Charger_Count).FirstOrDefault(),
                    UsedConnectorAmount = connectedConnectors.Where(x => x.CustomerName == customer.Name).Select(x => x.Charger_Count).FirstOrDefault(),
                    CreatedOn = DateTime.UtcNow
                });

                //ignore customer

                connectionStatistics.RemoveAll(x => x.StoragedChargerAmount == 0);
            }
            connectionStatistics.Add(new ConnectionStatistics()
            {
                CustomerName = "PHT",
                StationName = "PHT",
                StoragedChargerAmount = (await database.GetPHTChargerAmount(false, true)).Where(x => x.CustomerName == "PHT").Select(x => x.Charger_Count).FirstOrDefault(),
                UsedChargerAmount = (await database.GetPHTChargerAmount(true, true)).Where(x => x.CustomerName == "PHT").Select(x => x.Charger_Count).FirstOrDefault(),
                UsedConnectorAmount = (await database.GetPHTConnectorAmount(true)).Where(x => x.CustomerName == "PHT").Select(x => x.Charger_Count).FirstOrDefault(),
                CreatedOn = DateTime.UtcNow
            });

            connectionStatistics.Add(new ConnectionStatistics()
            {
                CustomerName = "PHT",
                StationName = "Electric Avenue",
                StoragedChargerAmount = (await database.GetPHTChargerAmount(false, false)).Where(x => x.CustomerName == "PHT").Select(x => x.Charger_Count).FirstOrDefault(),
                UsedChargerAmount = (await database.GetPHTChargerAmount(true, false)).Where(x => x.CustomerName == "PHT").Select(x => x.Charger_Count).FirstOrDefault(),
                UsedConnectorAmount = (await database.GetPHTConnectorAmount(false)).Where(x => x.CustomerName == "PHT").Select(x => x.Charger_Count).FirstOrDefault(),
                CreatedOn = DateTime.UtcNow
            });

            await database.SaveConnectionStatistics(connectionStatistics);
            logger.LogTrace(this.ToString() + " :Finished........");

        }
    }
}
