﻿using Microsoft.Extensions.Configuration;
using Microsoft.Extensions.DependencyInjection;
using Quartz;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace EVCB_OCPP.TaskScheduler.Jobs
{
    public static class JobScheduler
    {
        public static void AddTaskSchedulerQuartz(this IServiceCollection services, JobsConfig config)
        {
            services.AddQuartz(q => {

                q.UseMicrosoftDependencyInjectionJobFactory();

                q.ScheduleJob<CheckEVSEOnlineJob>(trigger =>
                    trigger
                    .WithIdentity("CheckEVSEOnlineJobTrigger")
                    .StartNow()
                    .WithSimpleSchedule(x => x
                        .WithIntervalInSeconds(10)
                        .RepeatForever())
                );

                q.ScheduleJob<StartTransacionReportJob>(trigger =>
                    trigger
                    .WithIdentity("StartTransacionReportJobTrigger")
                    .StartNow()
                    .WithSimpleSchedule(x => x
                        .WithIntervalInSeconds(10)
                        .RepeatForever())
                );

                q.ScheduleJob<StopTransacionReportJob>(trigger =>
                    trigger
                    .WithIdentity("StopTransacionReportJobTrigger")
                    .StartNow()
                    .WithSimpleSchedule(x => x
                        .WithIntervalInSeconds(10)
                        .RepeatForever())
                );

                q.ScheduleJob<CheckExecutionCmdJob>(trigger =>
                    trigger
                    .WithIdentity("CheckExecutionCmdJobTrigger")
                    .StartNow()
                    .WithSimpleSchedule(x => x
                        .WithIntervalInSeconds(5)
                        .RepeatForever())
                );

                q.ScheduleJob<ExecutionCmdReportJob>(trigger =>
                    trigger
                    .WithIdentity("ExecutionCmdReportJobTrigger")
                    .StartNow()
                    .WithSimpleSchedule(x => x
                        .WithIntervalInSeconds(10)
                        .RepeatForever())
                );

                q.ScheduleJob<ConnectionStatisticsJob>(trigger =>
                    trigger
                    .WithIdentity("ConnectionStatisticsJobTrigger")
                    .StartNow()
                    .WithCronSchedule("0 59 23 L * ?")
                );

                q.ScheduleJob<DeleteServerMessageJob>(trigger =>
                    trigger
                    .WithIdentity("DeleteServerMessageJobTrigger")
                    .StartNow()
                    .WithCronSchedule("0 15 17 * * ? *")
                );
            });

            services.AddQuartzHostedService(configure => {
                configure.WaitForJobsToComplete = true;
            });
        }
    }
}
