﻿using EVCB_OCPP.TaskScheduler.Helper;
using EVCB_OCPP.TaskScheduler.Services;
using Microsoft.Extensions.DependencyInjection;
using Microsoft.Extensions.Logging;
using Quartz;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace EVCB_OCPP.TaskScheduler.Jobs
{
    [DisallowConcurrentExecution]
    public class StartTransacionReportJob : IJob
    {
        private readonly ICustomersService customersService;
        private readonly DatabaseService databaseService;
        private readonly ILogger logger;

        public StartTransacionReportJob(
            ICustomersService customersService,
            DatabaseService databaseService,
            ILogger<StartTransacionReportJob> logger )
        {
            this.customersService = customersService;
            this.databaseService = databaseService;
            this.logger = logger;
        }
      

        public async Task Execute(IJobExecutionContext context)
        {
            using var timer = TimerHelper.Start(this.ToString(), logger);

            List<Task> tList = new List<Task>();

            var cList = await customersService.GetCallPartnerCustomers();

            var items = await databaseService.GetNeedReportStartTransactionSession();

            foreach (var customerId in cList)
            {
                if (customerId == new Guid("009E603C-79CD-4620-A2B8-D9349C0E8AD8")) continue;

                ICustomerService s = await customersService.GetCustomerService(customerId);

                //tList.Add(s.ReportStartTransaction());
                //tList.Add(DoMainTask(s));
                tList.Add(s.ReportStartTransaction(items.Where(x=>x.CustomerId == customerId).ToList()));
            }

            await Task.WhenAll(tList.ToArray());

            logger.LogInformation("{0} complete", this.ToString());
        }

        //private Task DoMainTask(ICustomerService _service)
        //{
        //    return _service.ReportStartTransaction();
        //}
    }
}
