﻿
using EVCB_OCPP.Domain.Extensions;
using EVCB_OCPP.TaskScheduler.Helper;
using EVCB_OCPP.TaskScheduler.Jobs;
using EVCB_OCPP.TaskScheduler.Services;
using Microsoft.Extensions.Configuration;
using Microsoft.Extensions.DependencyInjection;
using Microsoft.Extensions.Hosting;
using Microsoft.Extensions.Logging;
using NLog.Extensions.Logging;
using NLog.Web;
using Quartz;
using Quartz.Impl;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace EVCB_OCPP.TaskScheduler
{
    class Program
    {
        //static private NLog.ILogger logger = NLog.LogManager.GetCurrentClassLogger();

        private static void Main(string[] args)
        {
            Console.WriteLine("running....");
            IHost host = Host.CreateDefaultBuilder(args)
                .ConfigureLogging((context, builder) =>
                {
                    builder.ClearProviders();
                    NLog.LogManager.Configuration = new NLogLoggingConfiguration(context.Configuration.GetSection("NLog"));
                })
                .UseNLog()
                .ConfigureServices((context, services) => {

                    services.AddMainDbContext(context.Configuration);
                    services.AddOnlineLogDBContext(context.Configuration);
                    services.AddWebDBConetext(context.Configuration);

                    services.AddTransient<ICustomerService, CommonCustomerService>();
                    services.AddSingleton<ICustomersService, CustomersService>();

                    services.AddSingleton<MainDbService>();
                    services.AddSingleton<OnlineLogDbService>();
                    services.AddSingleton<DatabaseService>();
                    //services.AddTransient<OuterHttpClient>();

                    services.AddTaskSchedulerQuartz(context.Configuration.GetSection("Jobs").Get<JobsConfig>());
                    services.AddHostedService<TestService>();
                })
                .Build();
            host.Run();
        }
    }
}
