﻿using Microsoft.Extensions.DependencyInjection;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace EVCB_OCPP.TaskScheduler.Services;

public interface ICustomersService
{
    Task<ICustomerService> GetCustomerService(Guid guid);

    Task<List<Guid>> GetNotifyStopTransactionCustomers();

    Task<List<Guid>> GetCallPartnerCustomers();
}

public class CustomersService : ICustomersService
{
    private readonly IServiceProvider serviceProvider;
    private readonly DatabaseService _dbService;

    public CustomersService(IServiceProvider serviceProvider)
    {
        this.serviceProvider = serviceProvider; 
        this._dbService = serviceProvider.GetService<DatabaseService>();
    }

    public async Task<ICustomerService> GetCustomerService(Guid guid)
    {
        var service = serviceProvider.GetRequiredService<ICustomerService>();
        await service.SetCustomerId(guid);
        return service;
    }

    public Task<List<Guid>> GetCallPartnerCustomers()
    {
        return _dbService.GetCallParterAPICustomers();
    }

    public Task<List<Guid>> GetNotifyStopTransactionCustomers()
    {
        return _dbService.GetNotifyStopTransactionCustomers();
    }
}
