﻿using Dapper;
using EVCB_OCPP.Domain;
using EVCB_OCPP.Domain.ConnectionFactory;
using EVCB_OCPP.TaskScheduler.Helper;
using EVCB_OCPP.TaskScheduler.Models;
using Microsoft.Extensions.Logging;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace EVCB_OCPP.TaskScheduler.Services;

public class MainDbService
{
    public MainDbService(
        ISqlConnectionFactory<MainDBContext> connectionFactory
        , ILogger<MainDbService> logger)
    {
        this.sqlConnectionFactory = connectionFactory;
        this.logger = logger;

        InitUpdateEvseOnlineStatusHandler();
    }

    private readonly ISqlConnectionFactory<MainDBContext> sqlConnectionFactory;
    private readonly ILogger<MainDbService> logger;
    private GroupHandler<UpdateEvseOnlineModel> updateEvseOnlineStatusHandler;

    public Task UpdateEvseOnlineStatus(string ChargeBoxId, bool online, DateTime? offlineTime = null)
    {
        return updateEvseOnlineStatusHandler.HandleAsync(new UpdateEvseOnlineModel() { ChargeBoxId = ChargeBoxId, online = online, offlineTime = offlineTime });
    }

    private void InitUpdateEvseOnlineStatusHandler()
    {
        if (updateEvseOnlineStatusHandler is not null)
        {
            throw new Exception($"{nameof(InitUpdateEvseOnlineStatusHandler)} should only called once");
        }

        updateEvseOnlineStatusHandler = new GroupHandler<UpdateEvseOnlineModel>(
            //BulkInsertWithBulkCopy,
            BundleUpdateEvseOnlineStatus,
            //loggerFactory.CreateLogger("InsertMeterValueHandler")
            logger,
            workerCnt: 10
            );
    }

    private async Task BundleUpdateEvseOnlineStatus(BundleHandlerData<UpdateEvseOnlineModel> bundleData)
    {
        using var dbConn = await sqlConnectionFactory.CreateAsync();
        foreach (var data in bundleData.Datas)
        {
            string sqlString = $"""
            UPDATE dbo.Machine
            SET Online=@Online {(data.online? "": ", OfflineOn = @OfflineOn")}
            WHERE chargeBoxId = @ChargeBoxId
            """;

            var parameters = new DynamicParameters();
            parameters.Add("@Online", data.online, System.Data.DbType.Boolean);
            parameters.Add("@ChargeBoxId", data.ChargeBoxId, System.Data.DbType.String, System.Data.ParameterDirection.Input, 50);

            if (!data.online)
            {
                parameters.Add("@OfflineOn", data.offlineTime, System.Data.DbType.DateTime);
            }

            await dbConn.ExecuteAsync(sqlString, parameters);
            bundleData.AddCompletedData(data);
        }
    }
}

public record UpdateEvseOnlineModel
{
    public string ChargeBoxId;
    public bool online;
    public DateTime? offlineTime;
}
